@@ -58,9 +58,9 @@ mod deserializer;
 mod serialization_errors;
 mod serializer;
 
-pub use self::deserialization_errors::{ChunkDeserializationError, ChunkDeserializationErrorKind};
+pub use self::deserialization_errors::ChunkDeserializationError;
 pub use self::deserializer::ChunkDeserializer;
-pub use self::serialization_errors::{ChunkSerializationError, ChunkSerializationErrorKind};
+pub use self::serialization_errors::ChunkSerializationError;
 pub use self::serializer::{ChunkSerializer, Packet};
 
 #[cfg(test)]
