@@ -11,11 +11,9 @@ mod message_payload;
 mod serialization_errors;
 mod types;
 
-pub use self::deserialization_errors::{
-    MessageDeserializationError, MessageDeserializationErrorKind,
-};
+pub use self::deserialization_errors::MessageDeserializationError;
 pub use self::message_payload::MessagePayload;
-pub use self::serialization_errors::{MessageSerializationError, MessageSerializationErrorKind};
+pub use self::serialization_errors::MessageSerializationError;
 use bytes::Bytes;
 use rml_amf0::Amf0Value;
 use time::RtmpTimestamp;
