@@ -4,9 +4,7 @@ use rml_amf0::Amf0Value;
 use std::io::Cursor;
 
 use messages::RtmpMessage;
-use messages::{
-    MessageDeserializationError, MessageDeserializationErrorKind, MessageSerializationError,
-};
+use messages::{MessageDeserializationError, MessageSerializationError};
 
 pub fn serialize(
     command_name: String,
@@ -38,31 +36,23 @@ pub fn deserialize(data: Bytes) -> Result<RtmpMessage, MessageDeserializationErr
 
         command_name = match arg_iterator
             .next()
-            .ok_or(MessageDeserializationErrorKind::InvalidMessageFormat)?
+            .ok_or(MessageDeserializationError::InvalidMessageFormat)?
         {
             Amf0Value::Utf8String(value) => value,
-            _ => {
-                return Err(MessageDeserializationError {
-                    kind: MessageDeserializationErrorKind::InvalidMessageFormat,
-                })
-            }
+            _ => return Err(MessageDeserializationError::InvalidMessageFormat),
         };
 
         transaction_id = match arg_iterator
             .next()
-            .ok_or(MessageDeserializationErrorKind::InvalidMessageFormat)?
+            .ok_or(MessageDeserializationError::InvalidMessageFormat)?
         {
             Amf0Value::Number(value) => value,
-            _ => {
-                return Err(MessageDeserializationError {
-                    kind: MessageDeserializationErrorKind::InvalidMessageFormat,
-                })
-            }
+            _ => return Err(MessageDeserializationError::InvalidMessageFormat),
         };
 
         command_object = arg_iterator
             .next()
-            .ok_or(MessageDeserializationErrorKind::InvalidMessageFormat)?;
+            .ok_or(MessageDeserializationError::InvalidMessageFormat)?;
     }
 
     Ok(RtmpMessage::Amf0Command {
