@@ -3,18 +3,13 @@ use bytes::Bytes;
 use std::io::Cursor;
 
 use messages::RtmpMessage;
-use messages::{
-    MessageDeserializationError, MessageDeserializationErrorKind, MessageSerializationError,
-    MessageSerializationErrorKind,
-};
+use messages::{MessageDeserializationError, MessageSerializationError};
 
 const MAX_SIZE: u32 = 0x80000000 - 1;
 
 pub fn serialize(size: u32) -> Result<Bytes, MessageSerializationError> {
     if size > MAX_SIZE {
-        return Err(MessageSerializationError {
-            kind: MessageSerializationErrorKind::InvalidChunkSize,
-        });
+        return Err(MessageSerializationError::InvalidChunkSize);
     }
 
     let mut cursor = Cursor::new(Vec::new());
@@ -29,9 +24,7 @@ pub fn deserialize(data: Bytes) -> Result<RtmpMessage, MessageDeserializationErr
     let size = cursor.read_u32::<BigEndian>()?;
 
     if size > MAX_SIZE {
-        return Err(MessageDeserializationError {
-            kind: MessageDeserializationErrorKind::InvalidMessageFormat,
-        });
+        return Err(MessageDeserializationError::InvalidMessageFormat);
     }
 
     Ok(RtmpMessage::SetChunkSize { size })
