@@ -2,9 +2,7 @@ use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
 use bytes::Bytes;
 use std::io::Cursor;
 
-use messages::{
-    MessageDeserializationError, MessageDeserializationErrorKind, MessageSerializationError,
-};
+use messages::{MessageDeserializationError, MessageSerializationError};
 use messages::{PeerBandwidthLimitType, RtmpMessage};
 
 pub fn serialize(
@@ -33,9 +31,7 @@ pub fn deserialize(data: Bytes) -> Result<RtmpMessage, MessageDeserializationErr
         1 => PeerBandwidthLimitType::Soft,
         2 => PeerBandwidthLimitType::Dynamic,
         _ => {
-            return Err(MessageDeserializationError {
-                kind: MessageDeserializationErrorKind::InvalidMessageFormat,
-            })
+            return Err(MessageDeserializationError::InvalidMessageFormat);
         }
     };
 
