@@ -2,9 +2,7 @@ use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
 use bytes::Bytes;
 use std::io::{Cursor, Write};
 
-use messages::{
-    MessageDeserializationError, MessageDeserializationErrorKind, MessageSerializationError,
-};
+use messages::{MessageDeserializationError, MessageSerializationError};
 use messages::{RtmpMessage, UserControlEventType};
 use time::RtmpTimestamp;
 
@@ -46,9 +44,7 @@ pub fn deserialize(data: Bytes) -> Result<RtmpMessage, MessageDeserializationErr
         31 => UserControlEventType::BufferEmpty,
         32 => UserControlEventType::BufferReady,
         _ => {
-            return Err(MessageDeserializationError {
-                kind: MessageDeserializationErrorKind::InvalidMessageFormat,
-            })
+            return Err(MessageDeserializationError::InvalidMessageFormat);
         }
     };
 
