@@ -18,7 +18,6 @@ mod server;
 pub use self::client::ClientSession;
 pub use self::client::ClientSessionConfig;
 pub use self::client::ClientSessionError;
-pub use self::client::ClientSessionErrorKind;
 pub use self::client::ClientSessionEvent;
 pub use self::client::ClientSessionResult;
 pub use self::client::ClientState;
@@ -28,7 +27,6 @@ pub use self::server::PublishMode;
 pub use self::server::ServerSession;
 pub use self::server::ServerSessionConfig;
 pub use self::server::ServerSessionError;
-pub use self::server::ServerSessionErrorKind;
 pub use self::server::ServerSessionEvent;
 pub use self::server::ServerSessionResult;
 
