@@ -23,7 +23,7 @@ use std::time::SystemTime;
 use time::RtmpTimestamp;
 
 pub use self::config::ServerSessionConfig;
-pub use self::errors::{ServerSessionError, ServerSessionErrorKind};
+pub use self::errors::ServerSessionError;
 pub use self::events::{PlayStartValue, ServerSessionEvent};
 pub use self::publish_mode::PublishMode;
 pub use self::result::ServerSessionResult;
@@ -247,11 +247,7 @@ impl ServerSession {
     ) -> Result<Vec<ServerSessionResult>, ServerSessionError> {
         let request = match self.outstanding_requests.remove(&request_id) {
             Some(x) => x,
-            None => {
-                return Err(ServerSessionError {
-                    kind: ServerSessionErrorKind::InvalidRequestId,
-                })
-            }
+            None => return Err(ServerSessionError::InvalidRequestId),
         };
 
         match request {
@@ -434,11 +430,7 @@ impl ServerSession {
     ) -> Result<Vec<ServerSessionResult>, ServerSessionError> {
         let mut properties = match command_object {
             Amf0Value::Object(properties) => properties,
-            _ => {
-                return Err(ServerSessionError {
-                    kind: ServerSessionErrorKind::NoAppNameForConnectionRequest,
-                })
-            }
+            _ => return Err(ServerSessionError::NoAppNameForConnectionRequest),
         };
 
         let app_name = match properties.remove("app") {
@@ -450,17 +442,9 @@ impl ServerSession {
 
                     app
                 }
-                _ => {
-                    return Err(ServerSessionError {
-                        kind: ServerSessionErrorKind::NoAppNameForConnectionRequest,
-                    })
-                }
+                _ => return Err(ServerSessionError::NoAppNameForConnectionRequest),
             },
-            None => {
-                return Err(ServerSessionError {
-                    kind: ServerSessionErrorKind::NoAppNameForConnectionRequest,
-                })
-            }
+            None => return Err(ServerSessionError::NoAppNameForConnectionRequest),
         };
 
         self.object_encoding = match properties.remove("objectEncoding") {
@@ -1116,11 +1100,9 @@ impl ServerSession {
             }
 
             None => {
-                return Err(ServerSessionError {
-                    kind: ServerSessionErrorKind::ActionAttemptedOnInactiveStream {
-                        action: "publish".to_string(),
-                        stream_id,
-                    },
+                return Err(ServerSessionError::ActionAttemptedOnInactiveStream {
+                    action: "publish".to_string(),
+                    stream_id,
                 })
             }
         };
@@ -1177,11 +1159,9 @@ impl ServerSession {
             }
 
             None => {
-                return Err(ServerSessionError {
-                    kind: ServerSessionErrorKind::ActionAttemptedOnInactiveStream {
-                        action: "play".to_string(),
-                        stream_id,
-                    },
+                return Err(ServerSessionError::ActionAttemptedOnInactiveStream {
+                    action: "play".to_string(),
+                    stream_id,
                 });
             }
         }
